/***************************************************************************
                          appload11.cpp  -  description                              
                             -------------------                                         
    begin                : Mon Nov 15 22:43:31 WST 1999
                                           
    copyright            : (C) 1999 by Peter Gasparik                         
    email                : pgasparik@yahoo.com                                     
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   * 
 *                                                                         *
 ***************************************************************************/
#include <qkeycode.h>

#include "appload11.h"
#include "progressdialog.h"
#include "aboutdialog.h"
#include "configureportdialog.h"
#include "eesupport.h"

extern const char *pixmap_exit[];
extern const char *pixmap_config[];
extern const char *pixmap_help[];
extern const char *pixmap_about[];

Appload11::Appload11(QWidget *parent, const char *name) :
			MainDialog(parent, name)
{
	setCaption("Application Loader for 68HC11");
	
	MainMenu = new QMenuBar(this);
	FileMenu = new QPopupMenu;
	FileMenu->setCheckable(true);
	FileMenu->insertItem(QPixmap(pixmap_config), "&Configure Port...", this, SLOT(slotConfigPort()));
	EEMenuId = FileMenu->insertItem( "&EEPROM Support...", this, SLOT(slotEESupport()));
	FileMenu->insertSeparator();
	FileMenu->insertItem(QPixmap(pixmap_exit), "E&xit", this, SLOT(slotExit()));
	
	HelpMenu = new QPopupMenu;
	HelpMenu->insertItem(QPixmap(pixmap_help), "&Contents", this, SLOT(slotContents()));
	HelpMenu->insertSeparator();
	HelpMenu->insertItem(QPixmap(pixmap_about), "&About AppLoad11", this, SLOT(slotAboutApp()));
	
	MainMenu->insertItem("&File", FileMenu);
	MainMenu->insertItem("&Help", HelpMenu);

	// Restore settings
	KConfig *config = kapp->getConfig();
	config->setGroup("AppLoad");
	FileMenu->setItemChecked(EEMenuId, config->readNumEntry("EESup") > 0 ? true : false);
	
	UpdatePortLabel();	
}

Appload11::~Appload11()
{
}

void Appload11::UpdatePortLabel()
{
	KConfig *config = kapp->getConfig();
	config->setGroup("Port");
	QString port(config->readEntry("Port", NO_PORT));
	if (port == NO_PORT)
		PortLabel->setText("Not configured yet");
	else
	{
  	QString s;
  	s.sprintf("%s booting at %d, loading at %d",
  						port.data(),
  						config->readNumEntry("BootBaud", DEF_BOOT_BAUD),
  						config->readNumEntry("LoadBaud", DEF_LOAD_BAUD));
  	PortLabel->setText(s.data());
 	}
}

void Appload11::slotConfigPort()
{
	ConfigurePortDialog dlg(this);
	if (dlg.exec() == Accepted)
		UpdatePortLabel();
}

void Appload11::slotAboutApp()
{
	AboutDialog dlg(this);
	dlg.exec();
}

void Appload11::slotExit()
{
//	exit(0);
	accept();
}

void Appload11::slotContents()
{
	kapp->invokeHTMLHelp(QString("appload11/index.html"), QString(""));
}

void Appload11::slotEESupport()
{
	if (FileMenu->isItemChecked(EEMenuId))
		FileMenu->setItemChecked(EEMenuId, false);
	else
	{
		EESupport dlg(this);
		if (dlg.exec() == Accepted)
			FileMenu->setItemChecked(EEMenuId, true);
	}
	// save values
	KConfig *config = kapp->getConfig();
	config->setGroup("AppLoad");
	config->writeEntry("EESup", FileMenu->isItemChecked(EEMenuId) ? 1 : 0);
	config->sync();
}

void Appload11::keyPressEvent(QKeyEvent *e)
{
	// we don't want ESC to close main dialog
	if (e->key() == Key_Escape)
		e->ignore();
	else
		MainDialog::keyPressEvent(e);
}





