/***************************************************************************
                          configureportdialog.cpp  -  description                              
                             -------------------                                         
    begin                : Wed Nov 17 1999                                           
    copyright            : (C) 1999 by Peter Gasparik                         
    email                : pgasparik@yahoo.com                                     
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   * 
 *                                                                         *
 ***************************************************************************/
#include <fcntl.h>
#include <termios.h>
#include <stdio.h>
#include <stdlib.h>	
#include <unistd.h>
#include <string.h>


#include <kapp.h>
#include <kconfig.h>
#include <kfiledialog.h>
#include <qfileinfo.h>
#include <qmessagebox.h>

#include "configureportdialog.h"
#include "serialport.h"

extern const char *pixmap_fopen[];

ConfigurePortDialog::ConfigurePortDialog(QWidget *parent, const char *name) :
			QDialog(parent,name,true)
{
	initDialog();
	setCaption("Configure Serial Port");
	BrowseButton->setPixmap(QPixmap(pixmap_fopen));

	connect(RefreshButton, SIGNAL(clicked()), this, SLOT(slotRefresh()));
	connect(BrowseButton, SIGNAL(clicked()), this, SLOT(slotBrowse()));
	connect(OkButton, SIGNAL(clicked()), this, SLOT(slotOk()));
	connect(CancelButton, SIGNAL(clicked()), this, SLOT(reject()));
	connect(HelpButton, SIGNAL(clicked()), this, SLOT(slotHelp()));
	connect(SerPortsCombo, SIGNAL(activated(const char *)), this, SLOT(slotPortActivated()));

	// set user values
	KConfig *config = kapp->getConfig();
	config->setGroup("Port");
	QString serPort(config->readEntry("SerPort"));
	int i;
	for (i=0; i < SerPortsCombo->count(); i++)
		if (serPort == QString(SerPortsCombo->text(i)))
		{
			SerPortsCombo->setCurrentItem(i);
			break;
		}
	// make ttyS default
	if (i == SerPortsCombo->count())
		SerPortsCombo->setCurrentItem(2);
	
	UpdateAvailCombo();
	
	QString port(config->readEntry("Port"));
	for (int i=0; i < AvailCombo->count(); i++)
		if (port == QString(AvailCombo->text(i)))
		{
			AvailCombo->setCurrentItem(i);
			break;
		}
	
	QString baud;
	baud.sprintf("%d", config->readNumEntry("BootBaud", DEF_BOOT_BAUD));
	for (i=0; i < BootCombo->count(); i++)
	{
		if (baud == BootCombo->text(i))
		{
			BootCombo->setCurrentItem(i);
			break;
		}
	}
	if (i == BootCombo->count())
		BootCombo->setEditText(baud.data());
		
	baud.sprintf("%d", config->readNumEntry("LoadBaud", DEF_LOAD_BAUD));
	for (i=0; i < LoadCombo->count(); i++)
	{
		if (baud == LoadCombo->text(i))
		{
			LoadCombo->setCurrentItem(i);
			break;
		}
	}
	if (i == LoadCombo->count())
		LoadCombo->setEditText(baud.data());
		
	BootLoaderEdit->setText(config->readEntry("BootLoader", DEF_BOOTLOADER));
}

ConfigurePortDialog::~ConfigurePortDialog()
{
}

void ConfigurePortDialog::UpdateAvailCombo()
{
	AvailCombo->clear();

	for (int i=0; i < MAX_PORTS; i++)
	{
		QString DevName;
		DevName.sprintf("/dev/%s%d", SerPortsCombo->currentText(), i);
	  if (SerialPort::portExists(DevName.data()))
			AvailCombo->insertItem(DevName.data());
  }
}

void ConfigurePortDialog::slotOk()
{
	QFileInfo fInfo(BootLoaderEdit->text());
	if (!fInfo.exists())
	{
		QString text;
		text.sprintf("Boot loader \"%s\" doesn't exist at specified location.\nPlease select existing one.", fInfo.fileName().data());
		QMessageBox::warning(this, "Warning", text.data());
		BootLoaderEdit->setFocus();
		return;
	}
	
	// save values
	KConfig *config = kapp->getConfig();
	config->setGroup("Port");
	config->writeEntry("SerPort", SerPortsCombo->currentText());
	if (QString(AvailCombo->currentText()).length() == 0)
		config->writeEntry("Port", NO_PORT);
	else
		config->writeEntry("Port", AvailCombo->currentText());
	config->writeEntry("BootBaud", atoi(BootCombo->currentText()));
	config->writeEntry("LoadBaud", atoi(LoadCombo->currentText()));
	config->writeEntry("BootLoader", BootLoaderEdit->text());
	config->sync();
		
	accept();
}

void ConfigurePortDialog::slotRefresh()
{
	UpdateAvailCombo();
}

void ConfigurePortDialog::slotBrowse()
{
	// default to current bootloader
	QString name = KFileDialog::getOpenFileName(BootLoaderEdit->text(), "*.ihx *.hex|Intel HEX record (*.ihx *.hex)\n*.s19|Motorola S record (*.s19)\n*.*|All Files (*.*)", this);
	if (name.length() > 0)	
		BootLoaderEdit->setText(name.data());
}

void ConfigurePortDialog::slotHelp()
{
	kapp->invokeHTMLHelp(QString("appload11/index-3.html"), QString("ConfigDialog"));
}

void ConfigurePortDialog::slotPortActivated()
{
	UpdateAvailCombo();
}