/***************************************************************************
                          eesupport.cpp  -  description                              
                             -------------------                                         
    begin                : Mon Nov 22 1999                                           
    copyright            : (C) 1999 by Peter Gasparik                         
    email                : pgasparik@yahoo.com                                     
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   * 
 *                                                                         *
 ***************************************************************************/

#include <string.h>
#include <stdlib.h>
#include <stdio.h>

#include <qmessagebox.h>
#include <kapp.h>
#include <kconfig.h>

#include "eesupport.h"

EESupport::EESupport(QWidget *parent, const char *name) : QDialog(parent,name,true)
{
	initDialog();
	setCaption("Configure EEPROM");
	
	connect(CancelButton, SIGNAL(clicked()), this, SLOT(reject()));
	connect(OkButton, SIGNAL(clicked()), this, SLOT(slotOk()));
	connect(HelpButton, SIGNAL(clicked()), this, SLOT(slotHelp()));
	
	// load default value
	KConfig *config = kapp->getConfig();
	config->setGroup("EE");
	StartEdit->setText(config->readEntry("EEStart", "B600"));
	EndEdit->setText(config->readEntry("EEEnd", "B7FF"));
}

EESupport::~EESupport()
{
}

void EESupport::slotOk()
{
	// check if entered params are correct
	int start, end;
	if (sscanf(StartEdit->text(), "%8x", &start) == 0 || sscanf(EndEdit->text(), "%8x", &end) == 0 ||
		start > end || start > 0xFFFF || end > 0xFFFF)
	{
		QMessageBox::warning(this, "Warning", "Invalid Start / End address entered", QMessageBox::Ok, 0);
		StartEdit->setFocus();
		return;
	}
	// save values
	KConfig *config = kapp->getConfig();
	config->setGroup("EE");
	config->writeEntry("EEStart", StartEdit->text());
	config->writeEntry("EEEnd", EndEdit->text());
	config->sync();
		
	accept();
}

void EESupport::slotHelp()
{
	kapp->invokeHTMLHelp(QString("appload11/index-3.html"), QString("EEDialog"));
}
