/***************************************************************************
                          serialport.h  -  description                              
                             -------------------                                         
    begin                : Tue Dec 14 1999                                           
    copyright            : (C) 1999 by Peter Gasparik                         
    email                : pgasparik@yahoo.com                                     
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   * 
 *                                                                         *
 ***************************************************************************/

#ifndef SERIALPORT_H
#define SERIALPIRT_H

#include <termios.h>

#ifndef byte
typedef unsigned char byte;
#endif
#ifndef word
typedef unsigned short word;
#endif

#define	TIME_OUT			  2000                // in ms
#define MAX_PORTS    		16

/**
 * Simple serial communication class. <br>
 * Provides several open/close/read/write functions to transmit/receive data over
 * specified serial device. Modem control lines are not used as well as any software
 * control characters.<br>
 * It ispossible to specify baud rate, number of bits and parity.
 */
class SerialPort
{
private:
	bool	isOk;
	int		Handle;
	
	void Initialise();

public:
	SerialPort();
	SerialPort(const char *PortName, int Baud = B9600, int Format = CS8);
	virtual ~SerialPort();

	bool ok() { return isOk; };
	bool portOk() { return (Handle > 0); };
	bool openPort(const char *PortName, int Baud = B9600, int Format = CS8);
	void closePort();

	static bool portExists(const char *PortName);

 	int avail();
	void waitTxEmpty();
	bool receive(byte &Data, int TimeOut = TIME_OUT) { return receive(&Data, 1, TimeOut); }
	bool receive(word &Data, int TimeOut = TIME_OUT) { return receive((byte *)&Data, 2, TimeOut); }
	bool receive(byte *Data, int Len, int TimeOut = TIME_OUT);
	bool send(byte Value) { return send(&Value, 1); };
	bool send(word Value) { return send((byte *)&Value, 2); };
	bool send(byte *Data, int Len);
};

#endif
